==> GlsMapToolkit-API-1.10.1.zip: html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "GlsMap Toolkit", "index.html", [
    [ "GlsMap Toolkit API Reference", "index.html", [
      [ "What is the GlsMap Toolkit?", "index.html#top", null ],
      [ "Map Data Sources", "index.html#MapChartDataSources", [
        [ "DiSTI© Arbitrary Image Format (AIF)", "index.html#aifSource", null ],
        [ "Compressed ARC Digitized Raster Graphics (CADRG)", "index.html#cadrgSource", null ],
        [ "Digital Nautical Chart (DNC)", "index.html#dncSource", null ],
        [ "Digital Terrain Elevation Data (DTED)", "index.html#dtedSource", null ],
        [ "GeoTIFF Data Source (GeoTIFF)", "index.html#geoTIFFSource", null ],
        [ "Shapefile Data Source (Shapefile)", "index.html#shapefileSource", null ]
      ] ],
      [ "Additional Information", "index.html#addRef", null ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Related Functions", "functions_rela.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"classdisti_1_1_d_t_e_d_map_chart_data_source.html#abbaa13a66cadfc3b3c54b4779dda30a0",
"classdisti_1_1_map_chart_cell.html#a399f354da71f5bff924b210232851f65",
"functions_func_w.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> GlsMapToolkit-API-1.10.2.zip: html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "GlsMap Toolkit", "index.html", [
    [ "GlsMap Toolkit API Reference", "index.html", [
      [ "What is the GlsMap Toolkit?", "index.html#top", null ],
      [ "Map Data Sources", "index.html#MapChartDataSources", [
        [ "DiSTI© Arbitrary Image Format (AIF)", "index.html#aifSource", null ],
        [ "Compressed ARC Digitized Raster Graphics (CADRG)", "index.html#cadrgSource", null ],
        [ "Digital Nautical Chart (DNC)", "index.html#dncSource", null ],
        [ "Digital Terrain Elevation Data (DTED)", "index.html#dtedSource", null ],
        [ "GeoTIFF Data Source (GeoTIFF)", "index.html#geoTIFFSource", null ],
        [ "Shapefile Data Source (Shapefile)", "index.html#shapefileSource", null ]
      ] ],
      [ "Additional Information", "index.html#addRef", null ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Related Functions", "functions_rela.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"classdisti_1_1_d_t_e_d_map_chart_data_source.html#ab4653d0bfcfcedb58d2e1bcc074ce966",
"classdisti_1_1_map_chart_cell.html#a279aaec1e2f6fb998d97fdda75c1d9e8",
"functions_func_v.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
